aboutsummaryrefslogtreecommitdiff
path: root/requests/exceptions.py
diff options
context:
space:
mode:
Diffstat (limited to 'requests/exceptions.py')
-rw-r--r--requests/exceptions.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/requests/exceptions.py b/requests/exceptions.py
index 3c262e3..1cffa80 100644
--- a/requests/exceptions.py
+++ b/requests/exceptions.py
@@ -35,4 +35,7 @@ class MissingSchema(RequestException, ValueError):
"""The URL schema (e.g. http or https) is missing."""
class InvalidSchema(RequestException, ValueError):
- """See defaults.py for valid schemas.""" \ No newline at end of file
+ """See defaults.py for valid schemas."""
+
+class InvalidURL(RequestException, ValueError):
+ """ The URL provided was somehow invalid. """ \ No newline at end of file